#!/usr/bin/php -q
<?php
//-----------------------------------------------------------------------------
// version 1   Working at Potomac CC
// version 2   PCC specific code removed, upgraded SQL & php code, misc. enhancements
// version 3.0 April, 2016, additional enhancements, tracking of IP address, MySQL table changes
//-----------------------------------------------------------------------------

// This script is designed to run from a cron facility early in the mornings,
// probably about 2:30 a.m. Be aware of the difference between your local time
// and the time zone the seerver is in. The script reads through the volunteer
// database tables and emails a reminder to the volunteers a day ahead of time.
// For instance suppose the script runs on Friday morning at oh-dark-thirty.
// Your volunteer people will see the email during the day Friday and it will
// remind them of thier committment for the next day, Saturday.

// You can put this in a directory and treat it as a real web page, click on it,
// and it will send out reminders as appropriate. It produces NO OUTPUT, so you
// will not see any feedback. Beware that some impatient people will click it twice
// and then the reminders go out twice...

// Even more objectionable is that many of the reminder messages end up in
// a spam mailbox or do not make it at all.  Your mileage may vary.

//-----------------------------------------------------------------------------
// Connect to the database when running as a web page.
// If you are running from a cron facility, then the two include statements
// need to specify the full path name.
// for example /user/yourloginid/public_html/volunteers/db_connect.php
// inmotionhosting keeps gmt (uct) time, so it should be set to local timezone.
//-----------------------------------------------------------------------------
include("./set_timezone.php");
include("./db_connect.php");
$link = connectToMysqli();

//-----------------------------------------------------------------------------
// user should change the following variables / parameters
//-----------------------------------------------------------------------------
$days_ahead = 1;	// how many days ahead do you want to remind people? Tomorrow is 1.
$from_whom = "Jane Q. Public";
$reply_to = "webmaster@howardgriffin.org";
$contactEmail = "webmaster@howardgriffin.org";
$contactClub = "Favorite Curling Club";

//-----------------------------------------------------------------------------
// internal variables
//-----------------------------------------------------------------------------
$DEBUG = false;
if ($DEBUG) {echo date("l jS \of F Y h:i:s A");}
$zero_date  = "0000-00-00 00:00:00";
$tomorrow   = mktime(0, 0, 0, date("m"), date("d")+$days_ahead, date("y"));
$dayAfter   = mktime(0, 0, 0, date("m"), date("d")+$days_ahead+1, date("y"));
$startInSql = date("Y-m-d", $tomorrow);
$stopInSql  = date("Y-m-d", $dayAfter);
$i[0]=$i[1]=$i[2]=$i[3]=$i[4]=$i[5]=$i[6]=$i[7]=$i[8]="";
$j[0]=$j[1]=$j[2]=$j[3]=$j[4]=$j[5]=$j[6]=$j[7]=$j[8]="";
$k[0]=$k[1]=$k[2]=$k[3]=$k[4]=$k[5]=$k[6]=$k[7]=$k[8]="";

//-----------------------------------------------------------------------------
// first scan the volunteer opportunities table for anything happening tomorrow
//-----------------------------------------------------------------------------
$query1  = "select * from vol_task ";
$query1 .= "  WHERE (startTime >= '$startInSql')";
$query1 .= "  AND   (startTime <= '$stopInSql')";
$result1 = mysqli_query($link,$query1);
if (!$result1) {
	print "oops, something seems to have gone wrong with query1.<br>";
	print $query1;
	print "<br>sql error: " . mysqli_error($link) . "<br>";
	}

if ($DEBUG) {
	print "<p><font color='red'>query1: ";
	print "$query1 <br>";
	print mysqli_num_rows($result1);
	print " rows retrieved.</font><p>";
	}

while ($i=mysqli_fetch_row($result1)) {
	$taskID			= $i[0];
	$event_desc		= $i[1];
	$task_desc		= $i[2];
	$startTime		= $i[3];	// yyyy-mm-dd hh:mm:ss
	$stopTime		= $i[4];	// 0123456789*12345678
	$numVolunteers	= $i[5];
	$nonPubComments	= $i[6];
	$nonPubComments	= str_replace(",","",$nonPubComments);  // strip out commas so the .csv format works
 	$startHM = mktime(substr($startTime,11,2), substr($startTime,14,2), 0, substr($startTime,5,2), substr($startTime,8,2), substr($startTime,0,4) );

	//-------------------------------------------------------------------------
	// second find the people in each event
	//-------------------------------------------------------------------------
    $query2  = "SELECT * from `vol_people` ";
    $query2 .= " WHERE taskID=$taskID ";
    $query2 .= " AND date_removed='$zero_date' ";  // to make sure they are still a volunteer
	$result2 = mysqli_query($link,$query2);
	if (!$result2) {
		print "oops, something seems to have gone wrong with query2.<br>";
		print $query2;
		print "<br>sql error: " . mysqli_error($link) . "<br>";
		}

	if ($DEBUG) {
		print "<p><font color='red'>query2: ";
		print "$query2 <br>";
		print mysqli_num_rows($result2);
		print " rows retrieved.</font><p>";
		}

	while ($j=mysqli_fetch_row($result2)) {
		$curlerID		= $j[2];
		$date_added		= $j[3];

		//---------------------------------------------------------------------
		// third find the names of the people in each event
		//---------------------------------------------------------------------
		$query3  = "select fname, lname, email from curlers where curlerID = $curlerID";
		$result3 = mysqli_query($link,$query3);
			if (!$result3) {
			print "oops, something seems to have gone wrong with query3.<br>";
			print $query3;
			print "<br>sql error: " . mysqli_error($link) . "<br>";
			}
		$k=mysqli_fetch_row($result3); // only one row to be retrieved
		$fname	= $k[0];
		$lname	= $k[1];
		$email  = $k[2];

		if ($DEBUG) {
			print "<p><font color='red'>query3: ";
			print "$query3 <br>";
			print mysqli_num_rows($result3);
			print " rows retrieved.</font><p>";
			}

		//---------------------------------------------------------------------
		// now build the email message and ship it to each volunteer
		//---------------------------------------------------------------------
		$subject  = "$fname's volunteer reminder for ";
		$subject .= date("l, F jS", $tomorrow);

		$body  = "Dear $fname,\n\n";

		$body .= "Just a friendly reminder that you are volunteering ";
		$body .= "on " . date("l, F jS", $dayAfter) . " ";

		$body .= "starting at " . date("g:i a", $startHM) ;
		$body .= " as " . $task_desc . ". \r\n\r\n";

		$body .= "If you need to cancel your volunteer committment, please try and obtain a substitute ";
		$body .= "and contact the event coordinator to let them know about your change. \r\n\r\n";

		$body .= "We look forward to seeing you, and thanks in advance for ";
		$body .= "volunteering!  We really appreciate your service. \r\n\r\n";

		$body .= "***This email was sent from the $contactClub website. \r\n";
		$body .= "If you wish to report abuse of this service or you have any questions, ";
		$body .= "please contact $contactEmail. \r\n";
		$body .= "Please do not reply to this email as no human will ever see it.";

		$body = wordwrap($body, 70, "\r\n");

		$headers   = "From: $from_whom" . "\r\n";
		$headers  .= "Sender: $from_whom" . "\r\n";
		$headers  .= "Reply-To: $reply_to";

		if (!$DEBUG) mail($email,$subject,$body,$headers);

		if ($DEBUG) {
			print "<p>Date of event: ";
			print date("r", $startHM);
			print "<p>";
			print "email sent to: "; print $email;
			print "<p>";
			print "subject of mail: "; print $subject;
			print "<p>";
			print "body of mail:<br>"; print $body;
			print "<p>";
			print "headers: "; print $headers;
			print "<p>";
			}

		}	//end of selecting people loop
	}	//end of selecting events
?>
