<?php
session_start();
$currUser = "";
if (isset($_SESSION["currUser"])) $currUser = $_SESSION["currUser"];
?>
<!DOCTYPE html>
<html lang="en">
<head>
<meta name="author"              content="Howard Griffin">
<meta charset="utf-8" />
<meta name="viewport"            content="width=device-width, initial-scale=1.0">
<link rel="stylesheet"           type="text/css"     href="hgg_style.css">
<title>Volunteers</title>
</head>

<?php
//-----------------------------------------------------------------------------
// version 1   Working at Potomac CC
// version 2   PCC specific code removed, upgraded SQL & php code, misc. enhancements
// version 3.0 April, 2016, additional enhancements, tracking of IP address, MySQL table changes
//-----------------------------------------------------------------------------
$demoMode = true;		// if true we will NOT store email addresses. Use "false" for production.
$doISendEmail = false;	// true says really send mail, false says no.
$DEBUG=false;

//--------------------------------------------------------------------
// code to help manage volunteers. Based on the original code by
// Brian Galebach written in 2003, specific to bonspiels.
// It relied on email, which was unfortunately rejected by Comcast and other ISPs,
// So it worked but had limited success
//
// Completely re-written by Howard Griffin, October 2010, for generic events.
// Modernized (slightly) and posted for use on howardgriffin.org in June 2013.
//
// to get history, supply the start date yyyy-mm-dd in the url
// .../volunteers.php?start=2011-03-01
//
//--------------------------------------------------------------------
include("db_connect.php");
include("set_timezone.php");
$link = connectToMysqli();
include_once("data_valid_fns.php");

//--------------------------------------------------------------------
// Initialize variables that may be overwritten by arguments.
// This helps avoid warning and error messages.
//--------------------------------------------------------------------
// "GET" values passed via URL from column 4
$start = "";		// start date if not today, format is yyyy-mm-dd
$taskID = "";
$action = "";		// only 1 (volunteer) or 5 (unvolunteer) via GET
$curlerID = "";
$volunteerID = "";

// "POST" values passed via forms
$addCurler = "";
$fname = "";
$lname = "";
$database_email = "";
$email = "";
$form_email_addr = "";

//--------------------------------------------------------------------
// validate and assign arguments, GET or POST
// Edits are in:  data_valid_fns.php which must be included
//--------------------------------------------------------------------
// GET variables are passed via the url
if (isset($_GET["action"])) {
	if (good_digits($_GET["action"])) $action   = $_GET["action"];
	}
if (isset($_GET["curlerID"])) {
	if (good_digits($_GET["curlerID"])) $curlerID   = $_GET["curlerID"];
	}
if (isset($_GET["taskID"])) {
	if (good_digits($_GET["taskID"])) $taskID   = $_GET["taskID"];
	}
if (isset($_GET["volunteerID"])) {
	if (good_digits($_GET["volunteerID"])) $volunteerID   = $_GET["volunteerID"];
	}
if (isset($_GET["start"])) {
	if (good_datetime($_GET["start"])) $start  = $_GET["start"];
	}

if ($DEBUG) {
	print "<br>php_self: ".$_SERVER['PHP_SELF'];
	PRINT "<BR>request_uri: ".$_SERVER['REQUEST_URI']; // should include all url arguments
	print "<br><br>get taskID: ".$taskID;
	print "<br>get action: ".$action;
	print "<br>get start: ".$start;
	print "<br>get curlerID: ".$curlerID;
	print "<br>get volunteerID: ".$volunteerID;
	}

// POST variables come from a form
if (isset($_POST["action"])) {
	if (good_digits($_POST["action"])) $action   = $_POST["action"];
	}
if (isset($_POST["curlerID"])) {
	if (good_digits($_POST["curlerID"])) $curlerID   = $_POST["curlerID"];
	}
if (isset($_POST["taskID"])) {
	if (good_digits($_POST["taskID"])) $taskID   = $_POST["taskID"];
	}
if (isset($_POST["volunteerID"])) {
	if (good_digits($_POST["volunteerID"])) $volunteerID   = $_POST["volunteerID"];
	}
if (isset($_POST["form_email_addr"])) {
	if (good_email($_POST["form_email_addr"])) $form_email_addr = $_POST["form_email_addr"];
	}
if (!isset($_POST["form_email_addr"])) { // set to null to avoid errors on line ~271
	$form_email_addr = "";
	}
if (isset($_POST["addCurler"])) {
	if (good_digits($_POST["addCurler"])) $addCurler   = $_POST["addCurler"];
	}
if (isset($_POST["fname"])) {
	if (good_name($_POST["fname"])) $fname = $_POST["fname"];
	}
if (isset($_POST["lname"])) {
	if (good_name($_POST["lname"])) $lname = $_POST["lname"];
	}

if ($DEBUG) {
	print "<br><br>taskID: ".$taskID;
	print "<br>action: ".$action;
	print "<br>start: ".$start;
	print "<br>curlerID: ".$curlerID;
	print "<br>volunteerID: ".$volunteerID;
	print "<br>volunteerID: ".$volunteerID;
	print "<br>form_email_addr: ".$form_email_addr;
	print "<br>addCurler :".$addCurler;
	print "<br>fname: ".$fname;
	print "<br>lname: ".$lname;
	}

//--------------------------------------------------------------------
// General variables etc.
//--------------------------------------------------------------------
$contactClub  = "Your Curling Club";
$contactEmail = "webmaster@howardgriffin.org";
$contactName = "Clem Kadiddlehopper";
$webMaster = "webmaster@howardgriffin.org";		// back door, webmaster can un-volunteer somebody w/o sending email
$desiredVolunteers = 0;

//	This creates the header required for the SMTP mail server to send your email
//	"to" and "body" will be supplied later on.
$headers   = "From: $contactEmail\n";
$headers  .= "Sender: $contactEmail\n";
$headers  .= "Reply-To: $contactEmail\n";
$subjecty  = "Thank you for volunteering";
$subjecty .= " (sent " . date("m/d H.i ",time()) . ")";
$subjectn  = "Your volunteer committment was cancelled";
$subjectn .= " (sent " . date("m/d H.i ",time()) . ")";

$zero_date      = "0000-00-00 00:00:00";
$today_in_db    = date("Y-m-d G:i:s");
if ($start == "") $start = date("Y-m-d");	// if no start date is supplied via url arguments, use today


//////////////////////////////////////////////////////////////////////
// the following block of code is executed based on forms filled in
// and possible error messages. It is run before information is sent
// to the user browser window.  The order is important.
//////////////////////////////////////////////////////////////////////

//--------------------------------------------------------------------
// sometimes we need to add a new volunteer to the curlers table
// addcurler=1 means we asked for it, 2 means they gave it to us 0 means unnecessary
//--------------------------------------------------------------------
if (($addCurler == 2) AND ($fname != "") AND ($lname != "") AND ($form_email_addr != "")) {
	if ($demoMode) $form_email_addr = "not_saved";
	$fname = addslashes(stripslashes($fname));
	$lname = addslashes(stripslashes($lname));
	$query = "INSERT INTO curlers (fname, lname, email) values ('$fname','$lname','$form_email_addr')";
	$result = mysqli_query($link,$query);
	if ($DEBUG) print "<br>query 187".$query ;
	if (!$result==1) {
		print "oops, something seems to have gone wrong with adding to the curlers table.";
		print "<br>sql error: ".mysqli_error($link)."<br>";
		}
	}

//--------------------------------------------------------------------
// Action == 2, they supplied names, try and add them to the tables
//--------------------------------------------------------------------
if ($action == 2) {
	//----------------------------------------------------------------
	// first find the curlerID, unfortunately ignoring possible duplicates for now.
	//----------------------------------------------------------------
	$fname = addslashes(stripslashes($fname));
	$lname = addslashes(stripslashes($lname));
	$query6  = "SELECT * from curlers where fname='$fname' AND lname='$lname' LIMIT 1";
	$result6 = mysqli_query($link,$query6);
	if ($DEBUG) print "<br>query6: ".$query6;
	if (!$result6) {
		print "oops, something seems to have gone wrong with the find-a-curler.<br>";
		print $query6;
		print "<br>sql error: " . mysqli_error($link) . "<br>";
		}
	$numrows6 = mysqli_num_rows($result6);
	if ($numrows6 == 1) {
		$row = mysqli_fetch_row($result6);	// only one row expected
		$curlerID = $row[0];
		$database_email = $row[3];
		mysqli_free_result($result6);
		}
	if ($numrows6 == 0) {
		$action=4; // name not found in the curlers table
		}
	//----------------------------------------------------------------
	// if found, insert the curler in the vol_people table
	//----------------------------------------------------------------
	if ($numrows6 == "1") {
		$query7  = "INSERT INTO vol_people (taskid, curlerID, date_added, date_removed) ";
		$query7 .= " values ('$taskID','$curlerID','$today_in_db','$zero_date')";
		$result7 = mysqli_query($link,$query7);
		if ($DEBUG) print "<br>$query7: ".$query7;
		if (!$result7) {
			print "oops, something seems to have gone wrong with the query7 insert-a-volunteer.<br>";
			print $query7;
			print "<br>sql error: " . mysqli_error($link) . "<br>";
			$curlerID = "";
			}
		$action=3;	// inserted name OK
		}
	} // end of action == 2

//--------------------------------------------------------------------
// Action == 6, someone requested to be removed and supplied an email address
//--------------------------------------------------------------------
if ($action == "6") {
	$didItMatch = 0;	// assume the supplied email does not match the database
	$action = 8; 		// causes the prompt to be displayed again

	$query7  = "SELECT email from curlers where curlerID = $curlerID";
	$result7 = mysqli_query($link,$query7);
	if ($DEBUG) print "<br>query7 248:".$query7;
	if (!$result7) { // shouldnt fail because it got in there in the first place
		print "oops, something seems to have gone wrong with the cancel email query.<br>" ;
		print $query7 . "<br>";
		print "<br>sql error: " . mysqli_error($link) . "<br>";
		}
	$row = mysqli_fetch_row($result7);
    $database_email = strtolower($row[0]);
	if ($database_email == strtolower($form_email_addr)) $didItMatch=1;
	if ($webMaster == strtolower($form_email_addr)) $didItMatch=1; // back door

	// on occasion the following "if" generates an error that I cannot duplicate. Usually there
	// are five or six within a few seconds leading me to think it is a script or web crawler.
	// the error reads...
	// time stamp then "PHP Notice:  Undefined index: form_email_addr in" this file on the next line.
	if ( ($demoMode) AND ("not_saved"==$_POST["form_email_addr"]) ) $didItMatch=1;

	//----------------------------------------------------------------
	// The email address matched, so go ahead and unvolunteer them
	//----------------------------------------------------------------
	if ($didItMatch) {
		$query8  = "UPDATE vol_people SET date_removed='$today_in_db' ";
		$query8 .= " WHERE (volunteerID='$volunteerID' ";
		$query8 .= "   AND curlerID='$curlerID' AND date_removed='$zero_date') ";
		$query8 .= " LIMIT 1";
		$result8 = mysqli_query($link,$query8);
		if ($DEBUG) print "<br>query8: ".$query8;
		if (!$result8) {
			print "oops, something seems to have gone wrong with the cancellation table update.<br>" ;
			print $query;
			print "<br>sql error: " . mysqli_error($link) . "<br>";
			}
		$action = "7"; // successful delete, so re-show the page with adios message.
		}
	if (!$didItMatch) $action = 8;
	}	// end of action == 6

//////////////////////////////////////////////////////////////////////
// end of the block of code run before the info is sent to the browser
//////////////////////////////////////////////////////////////////////
?>

<body>
<a id="top"></a>

<?php
include("masthead.php");
if ($demoMode) {
	print "<p style='background:yellow; margin:0px;'>"; // 0px margin on all 4 sides
	print "We are running in &quot;demo&quot; mode, which simply means ";
	print "that your email address will not be stored. Insted we will ";
	print "store the address of &quot;not_saved&quot;. ";
	print "We will still edit the email address for correct formatting, ";
	print "but won't save it. To cancel the reservation, please enter &quot;not_saved&quot;.";
	print "<br>In a production environment, you will not see this yellow message box.";
	print "</p>";
	}

print "<blockquote>";
//--------------------------------------------------------------------
// If you are logged in, you can navigate back to the
// manageVolunteerEvents.php page or logout.
//--------------------------------------------------------------------
if ($currUser != "") {  // session variable, not a get or put type variable
	// print("<a href='manageVolunteerEvents.php'>manage events</a>");
	include("logoutButton.php");
	print "<br><form action=\"manageVolunteerEvents.php\">";
	print "<input type=\"submit\" value=\"Back to managing events\">";
	print "</form>";
	}

print "<table style=\"width:680px\"> ";	// start the table of text & pic
print "<tr><td colspan=\"3\"> ";		// with explanations

//////////Warning notices start here, centered on the real data, not screen width ///////

//--------------------------------------------------------------------
// Decide what to do based on the action argument
// if ($action == 2) // they supplied names, nothing to do here it is all handled above the html
// if ($action == 5) // they pressed the *remove* link, but first see if they are human or web crawlers
//--------------------------------------------------------------------

//--------------------------------------------------------------------
// Action == 4, the add failed, cannot find them in curlers table.
//--------------------------------------------------------------------
if ($action == 4) {
	print "<table class=\"alertBox\" style=\"background-color:yellow;\"><tr><td>";
	print "We could not find you in our curlers table!";
	print "<br>Possible causes could be a typo or that simply we've never added you";
	print "<br>Or possibly the email address failed the edits :(";
	print "<br><br>If you are a NEW volunteer, GREAT, THANKS!<br>";
	print "<span style=\"color:red\">Please give us your valid email address</span> ";
	print "so we know you are a human, instead of a web crawler.";
	print "</td></tr></table>";
	$action = 1;
	$addCurler = 1;  // means we ask them for their email addess
	}

//--------------------------------------------------------------------
// Action == 1, they pressed the "I want to volunteer" link below
//--------------------------------------------------------------------
if ($action == 1) {
	print "  <form name=add action=\"$_SERVER[PHP_SELF]\" method=\"POST\">\n";
	print "    <input type='hidden' name=taskID value=$taskID>\n";
	print "    <input type='hidden' name=action value=2>\n";
	print "<table class=\"alertBox\">\n";
	print "  <tr>\n";
	print "    <td>First Name</td>\n";
	print "    <td>Last Name</td>\n";
	print "  </tr>\n";
	print "  <tr>\n";
	$fname = stripslashes($fname);
	$lname = stripslashes($lname);
	print "    <td><input type=text name=fname value=\"$fname\" size='25' maxlength='25'></td>\n";
	print "    <td><input type=text name=lname value=\"$lname\" size='25' maxlength='35'></td>\n";
	if ($addCurler == 1) {  // here is where we ask for the email address for a new volunteer
		print "<tr><td colspan='2'>\n";
		print "<input type='hidden' name=addCurler value=2>\n";  // set it to 2 if they give it to us
		print "email: <input type=text name=form_email_addr  value=\"$email\" size='35' maxlength='80'>\n";
		print "</td></tr>\n";
	    }
	print "<tr><td colspan='2' style='text-align:center;'>\n";
	print "<input type='submit' value='Submit'></td></tr>";
	print "</table>\n";
	print "</form>\n";

	// set the focus on the first name or form_email_addr
	print "<script>";
	if ($addCurler) print "document.forms['add'].elements['form_email_addr'].focus(); ";
	else print "document.forms['add'].elements['fname'].focus(); ";
	print "</script>";
	}

//--------------------------------------------------------------------
// Action == 3, successfully added someone, now send them a note
//--------------------------------------------------------------------
if ($action == 3) {
	print "<table class=\"alertBox\"><tr><td style=\"background-color:#90ee90;padding:10px;text-align:center;\">";
	print "You have been added<br>Thank You for volunteering!";
	print "</td></tr></table>";
	$action  = "";

	//----------------------------------------------------------------
	// pull the task info from the DB, send them a thank-you note
	//----------------------------------------------------------------
	$query     = "SELECT event_desc, task_desc, startTime, stopTime FROM vol_task WHERE taskID = $taskID ";
	$result    = mysqli_query($link,$query);
	if (!$result) {
		print "<br>".$query;
		print "<br>".mysqli_error($link);
		}
	$row = mysqli_fetch_row($result);  // only one row expected
	$email_event     = $row[0];
	$email_task      = $row[1];
	$email_startTime = date("g:i a",strtotime($row[2]));
	$email_theDay    = date("l, F jS",strtotime($row[2]));
	$email_stopTime  = date("g:i a",strtotime($row[3]));
	$body  = "Thank you for volunteering!\n\n";
	$body .= "You, or someone representing themselves as you, has entered your name as a volunteer ";
	$body .= " for $contactClub. Specifically your name was entered as a volunteer...";
	$body .= "\n\n for " . $email_event;
	$body .= "\n as " . $email_task;
	$body .= "\n on " . "$email_theDay";
	$body .= "\n from " . $email_startTime;
	$body .= " to " . $email_stopTime;
    $body .= "\n\n***This email was sent from the $contactClub website. \n";
    $body .= "If you wish to report abuse of this service or you have any questions, \n";
    $body .= "please contact $contactName at $contactEmail.";
	if ($demoMode) {
		$database_email = "not_saved";
		$doISendEmail = false;	// because the email address is bogus, do not even try.
		}
	// This one line actually sends the mail
	if($doISendEmail) mail($database_email,$subjecty,$body,$headers);
	if ($DEBUG) {
		print "<br>database email: ".$database_email;
		print "<br>subj y: ".$subjecty;
		print "<br>".$body;
		print "<br>".$headers;
		}
	} // end of if action==3

//--------------------------------------------------------------------
// Action == 8, passwords did not match
//--------------------------------------------------------------------
if ($action == 8) {
	print "<table class=\"alertBox\" style=\"width:400px\">";
	print "<tr><td style=\"background-color:#ffd700;padding:10px;text-align:center;\">";
	print "The email address supplied did not match what we have on file.<br>Please correct and resubmit.";
	print "</td></tr></table>";
	$action  = 5;
	}

//--------------------------------------------------------------------
// Action == 5, someone requested to be removed from the list
//             if they give us an email address, set action = 6 to process
//--------------------------------------------------------------------
if ($action == 5) {
	print "<table class=\"alertBox\" style=\"width:400px;\"><tr><td>";
	print "<span style=\"color:red\">You requested to be removed from the volunteer list for an event.</span><br>";
	print "Web crawlers and spiders (Yahoo, Google, and a variety of others, including crawlers ";
	print " from Russia and China walk through our site on a regular basis. Unfortunately ";
	print " this means they also click on our links, including the *remove* link, which can ";
	print " have unfortunate consequences.  So to avoid that situation, we ask that you supply ";
	print " your email address as confirmation that you are indeed a human seeking to ";
	print " &quot;unvolunteer&quot; from a particular event.";
	print "</td></tr>";

	print "<tr><td class=\"tdcenter\">";
	print "<form name=cancelRes action=\"$_SERVER[PHP_SELF]\" method=\"POST\">";
	$action = 6;
	print "<span style=\"color:red\">May we have your email address please? </span>";
	print "<input type='hidden' name=action    value='$action'>";
	print "<input type='hidden' name=curlerID  value='$curlerID'>";
	print "<input type='hidden' name=taskID    value='$taskID'>";
	print "<input type='hidden' name=volunteerID value='$volunteerID'>";
	if ($demoMode) $email = "enter &quot;not_saved&quot; here";	// populate the box for them, because they will not read...
	print "<input type=text     name=form_email_addr  placeholder=\"$email\" size='35' maxlength='80' aria-required='true' required><br>";
	print "<input type='submit' value=\"Cancel My Volunteer Committment\">";
	print "</form>";
	print "</td></tr></table>";

	// set the focus on the email address, could use autofocus in the actual input type for new browsers
	print "<script>";
	print "document.forms['cancelRes'].elements['form_email_addr'].focus(); ";
	print "</script>";
    }

//--------------------------------------------------------------------
// Action == 7, successfully deleted someone
//--------------------------------------------------------------------
if ($action == 7) {
	print "<table class=\"alertBox\"><tr><td style=\"background-color:#0088ff;padding:10px;text-align:center;\">";
	print "You have been removed!";
	print "</td></tr></table>";
	$action  = "";

	//----------------------------------------------------------------
	// pull the task info from the DB, send them a note that they just *unvolunteered*
	//----------------------------------------------------------------
	$query     = "SELECT event_desc, task_desc, startTime, stopTime FROM vol_task WHERE taskID = $taskID ";
	$result    = mysqli_query($link,$query);
	$row = mysqli_fetch_row($result);	// only one row expected
	$email_event     = $row[0];
	$email_task      = $row[1];
	$email_startTime = date("g:i a",strtotime($row[2]));
	$email_theDay    = date("l, F jS",strtotime($row[2]));
	$email_stopTime  = date("g:i a",strtotime($row[3]));
	$body  = "Your request to withdraw your volunteer offer has been processed.\n\n";
	$body .= "You, or someone representing themselves as you, has removed your name from the volunteer ";
	$body .= " sign-up for the $contactClub. Specifically your name was removed as a volunteer...";
	$body .= "\n\n from " . $email_event;
	$body .= "\n as " . $email_task;
	$body .= "\n on " . "$email_theDay";
    $body .= "\n\n***This email was sent from the $contactClub website. \n";
    $body .= "If you wish to report abuse of this service or you have any questions, \n";
    $body .= "please contact $contactName at $contactEmail.";

	if ($webMaster != strtolower($form_email_addr)) { // back door
		// do not send email if webmaster cancels somebody, usually because they were a no-show
		if ($demoMode) {
			$database_email = "not_saved";
			$doISendEmail = false;	// because the email address is bogus, do not even try.
			}
		// This next line actually sends the mail
		if($doISendEmail) mail($database_email,$subjectn,$body,$headers);
		if ($DEBUG) {
			print "<br>database email: ".$database_email;
			print "<br>subj n: ".$subjectn;
			print "<br>".$body;
			print "<br>".$headers;
			}
		}
	} // end of action 7

//////////Warning notices stop here ////////////////////////////////////////////////////
?>

  </td></tr>


  <tr>
    <td colspan="2"><p class="pcc3center">Volunteer Opportunities</p>
		<p>The success of our organization depends on our volunteers. We are all
	      volunteers of one sort or another, so please consider signing up for a
		  volunteer opportunity listed below. You may either scroll down or
		  select the links below to jump to the paticular event.</p>

		<p>
		  You may choose a different start date by including the start date in the url as follows:<br>
		  .../volunteers.php?start=2019-03-05</p>
	</td>
    <td style="width:250px" rowspan="2"><img src="wec-help.jpg" alt="please help"></td>
  </tr>
  <tr>
    <td style="width:148px">
	<?php
	//--------------------------------------------------------------------
	// Pull off the event descriptions, to be used as anchors at the top of the page
	//--------------------------------------------------------------------
	$query1   = "SELECT event_desc, startTime FROM vol_task ";
	$query1  .= " WHERE  startTime >= '$start' ";
	$query1  .= " ORDER BY event_desc, startTime ";
	$result1  = mysqli_query($link,$query1);
	$numrows1 = mysqli_num_rows($result1);
	$oldevent = "";
	$tagnum = 0;

	print "<ul>";
	while ($row = mysqli_fetch_row($result1)) {
		$event = $row[0];
		if ($event !== $oldevent) {
			print "<li><a href=\"#tag" . $tagnum . "\">" . $event . "</a></li>\n";
			$oldevent = $event ;
			$tagnum++;
			}
		}
	if ($numrows1 == 0) print "<li>There are no active volunteer requests outstanding.</li>";
	print "</ul>";
	?>

	</td>
    <td style="width:265px">
	<span style="color:red">Click to volunteer</span> means that we are still looking for
		volunteers, especially for the larger events.<br>
    <span style="color:red">Extras welcome</span> means that we are probably fully staffed,
		but of course extra help is always appreciated.</td>
    </tr>
</table>  <!-- end of table of text and picture -->


<?php
//--------------------------------------------------------------------
// now build the tables for each event, separated by named anchor tags
// it is the same loop as query1 so we will re-use the query, but we must
// run it again as the result cannot be reused.
// then query for the rest, and at the end put in a back-to-top tag.
//--------------------------------------------------------------------
$oldevent = "";
$tagnum=0;
$result1  = mysqli_query($link,$query1);	// rerun query1
while ($row = mysqli_fetch_row($result1)) {
	$event = $row[0];
	if ($event !== $oldevent)
	{
	print "<br><strong><a id=\"tag".$tagnum."\">" . $event . "</a></strong><br>\n";  // name of anchor tag
	$tagnum++;	// increment now so you do not forget it later
	//----------------------------------------------------------------
	// headers for the table that holds each event
	// the entire table is a form to prevent blank lines inside table cells
	//----------------------------------------------------------------
	print "<table class=\"withBorder\">\n";

	print "<tr>\n";
		print "<td>Date</td>\n";
		print "<td>Time</td>\n";
		print "<td>Opportunities</td>\n";
		print "<td>Volunteers</td>\n";
	print "</tr>\n";

	//----------------------------------------------------------------
	// select the info for the first (date) column
	//----------------------------------------------------------------
	$query2   = "SELECT DISTINCT (DATE_FORMAT(startTime,\"%W, %M %D, %Y\")) AS dates, ";
	$query2  .= " TO_DAYS(startTime) AS daynums, ";
	$query2  .= " FROM_DAYS(TO_DAYS(startTime)) AS justdays ";
	$query2  .= " FROM vol_task WHERE event_desc ='$event' AND startTime >= '$start' ";
	$query2  .= " ORDER BY startTime ";
	$result2  = mysqli_query($link,$query2);
	$numdays  = mysqli_num_rows($result2);

	while ($row1 = mysqli_fetch_row($result2)) {
		$currdate = $row1[0];
		$justday  = $row1[2];
		$query3   = "SELECT taskID, task_desc, DATE_FORMAT(startTime,\"%l:%i %p\") AS start, ";
		$query3  .= " DATE_FORMAT(stopTime,\"%l:%i %p\") AS stop, numVolunteers ";
		$query3  .= " FROM vol_task WHERE event_desc ='$event' AND startTime LIKE '$justday%' ORDER BY startTime";
		$result3  = mysqli_query($link,$query3);
		$numtasks = mysqli_num_rows($result3);
		print "<tr>";
		print "<td rowspan=\"$numtasks\">$currdate &nbsp;</td>\n";  // print first column

	//----------------------------------------------------------------
	// select the info for the second (time) and third (task description) column
	//        this column may have multiple rows (many times for same date)
	//----------------------------------------------------------------
		for ($tasknum=0; $tasknum<$numtasks; $tasknum++) {
			$row3 = mysqli_fetch_row($result3);
			$taskID 	= $row3[0];
			$task		= $row3[1];
			$startTime	= $row3[2];
			$stopTime	= $row3[3];
			$numVolunteers = $row3[4];

			if ($tasknum>0) print "<tr>\n";	// second and subsequent rows within date (col 1)

			print "<td>$startTime &#8211; $stopTime &nbsp;</td>\n";  // print second column
			print "<td>$task &nbsp;</td>\n";               // print third column

	//----------------------------------------------------------------
	// select the info for the fourth (volunteers) column,
	// allow for more actual volunteers than requested in the vol_task table
	//----------------------------------------------------------------
			print "<td>\n";	// start 4th column
			$query5  = "SELECT * from vol_people ";
			$query5 .= " WHERE taskID=$taskID ";
			$query5 .= " AND date_removed='$zero_date' ";
			$result5 = mysqli_query($link,$query5);
			$moreThanExpected = mysqli_num_rows($result5);
			if ($moreThanExpected > $numVolunteers) {
				$desiredVolunteers = $numVolunteers;
				$numVolunteers = $moreThanExpected;
				}
			$available=0;
			for ($j=0; $j<$numVolunteers; $j++) {
				$query4   = "SELECT curlerID, volunteerID FROM vol_people ";
				$query4  .= " WHERE taskID=$taskID ";
				$query4  .= " AND date_removed='$zero_date' ";
				$query4  .= " ORDER BY volunteerID LIMIT $j,1";
				$result4  = mysqli_query($link,$query4);
				if (mysqli_num_rows($result4)) {
					$row4 = mysqli_fetch_row($result4);
					$curlerID    = $row4[0];
					$volunteerID = $row4[1];
					$query5      = "SELECT CONCAT(fname,\" \",lname) AS name ";
					$query5     .= " FROM curlers WHERE curlerID=$curlerID";
					$result5     = mysqli_query($link,$query5);
					$row5 = mysqli_fetch_row($result5);
					$name = $row5[0];
					$name .= " <a href=\"$_SERVER[PHP_SELF]?action=5&amp;taskID=$taskID&amp;curlerID=$curlerID&amp;volunteerID=$volunteerID\">[Remove]</a>";
					if ($desiredVolunteers == ($j+1)) $name .= "<br>----------"; // if you already have enough volunteers
					}
				else {
					$available++;
					if ($available>1) $name = "";
					else {
						// $action=1; // someone who wants to volunteer clicks here
						$name = "<a href=\"$_SERVER[PHP_SELF]?taskID=$taskID&amp;action=1\">Click to volunteer.</a>";
						}
					}
				$volnum=$j+1;
				print "$volnum. $name \n";
				if ($volnum<$numVolunteers) print "<br>";
			}	// end of loop for volunteers already signed up column


			//--------------------------------------------------------
			// you have enough volunteers, but more are always welcome
			// $name of null says you still have more than one opening,
			//		so no need to add an extra
			// but then again 'click to volunteer' could be in the last string,
			//		if so there is still no need to add extra
			//--------------------------------------------------------
			$findme = "Click to volunteer";
			if (($name !== "") AND (!stripos($name,$findme))) {
				$volnum=$volnum+1;
				$name = "<a href=\"$_SERVER[PHP_SELF]?taskID=$taskID&amp;action=1\">Extras welcome</a>";
				print "<br>$volnum. $name \n";
				}
    		print "</td>\n";	// end of 4th column, either blanks or *extras welcome*
			print "</tr>\n";
			// print "<tr><td colspan='4'> DEBUG line 698 </td></tr>";
		}	// end of loop for second and third columns (time and opportunity)
	}	// end of loop for first column (date)

	//----------------------------------------------------------------
	// end the table that holds each event
	//----------------------------------------------------------------
	print "</table>";
	print "<a href=\"#top\">Back To Top\n</a><br>";

	$oldevent = $event ;
	}	// end of if event !== oldevent
}	// end of loop building tables for each event type

print "</blockquote>";

?>

</body>
</html>
